Integrations
============

Integration classes for Sentence Transformers and other frameworks.

Sentence Transformers
---------------------

RKSentenceTransformer
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: rktransformers.integrations.sentence_transformers.RKSentenceTransformer
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

RKCrossEncoder
~~~~~~~~~~~~~~

.. autoclass:: rktransformers.integrations.sentence_transformers.RKCrossEncoder
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__
